/*
 * dclock messages for Japanese
 *   By: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>
 *   Modified by: YAMAGUCHI Shingo <shingo-y@spacelan.ne.jp>
 */

#ifndef __DCLOCK_MSG_JA_H__
#define __DCLOCK_MSG_JA_H__

#define POPEX_STRING		"ߤ͸"
#define PEOPLE_STRING		" "
#define FOREST_STRING		"ߤǮӱӤ"
#define TROPICAL_STRING		" "
#define HIV_STRING		"ߤ HIV "
#define CASES_STRING		" "
#define LAB_STRING		"ǯưʪ¸ˤ"
#define VEG_STRING		"ǯʹ֤οȤȤ"
#define YEAR_STRING		" Τưʪˤʤޤ"
#define Y2K_STRING		"Y2K (2000ǯ11, 000ʬ00) ޤ "
#define POST_Y2K_STRING		"Y2K (2000ǯ11, 000ʬ00) "
#define Y2001_STRING		"ǯνλ (2001ǯ11, 000ʬ00) ޤ "
#define POST_Y2001_STRING	"ǯγ (2001ǯ11, 000ʬ00) "
#define MAYAN_STRING		"Countdown to 13th bak'tun (21 December 2012)"
#define POST_MAYAN_STRING	"Countdown to 13th bak'tun (21 December 2012)"
#define DAY			""
#define DAYS			""
#define HOUR			""
#define HOURS			""
#define MINUTE			"ʬ"
#define MINUTES			"ʬ"
#define SECOND			""
#define SECONDS			""

#ifdef METRIC
#define AREA_STRING		"إ"
#else
#define AREA_STRING		""
#endif

#endif /* __DCLOCK_MSG_JA_H__ */
